@@ -10,20 +10,18 @@ use namespace::autoclean;
 
 sub request {
     my ( $self, $request ) = @_;
-    my $path = sprintf '%s/http_response/%s', dirname(__FILE__), $request->uri->path;
+    my $path = sprintf '%s/http_response/%s/%s.%s', dirname(__FILE__), $request->uri->host, $request->uri->path, $request->method;
     my %query_form = $request->uri->query_form;
     while ( my ( $k, $v ) = each %query_form ) {
         $path .= sprintf '.%s-%s', $k, $v;
     }
-    my $res;
     if ( -f $path ) {
-        $res = read_file($path);
+        my $res = read_file($path);
+        return HTTP::Response->parse($res);
     }
-    elsif ( -d $path && -f "${path}/index" ) {
-        $res = read_file("${path}/index");
-    }
-    return HTTP::Response->parse($res) if $res;
-    return HTTP::Response->new;
+    my $response = HTTP::Response->new;
+    $response->request($request);
+    return $response;
 }
 
 __PACKAGE__->meta->make_immutable;
